@@ -6,19 +6,24 @@
 #' The value is calculated using the value function stored in the POMDP
 #' solution.
 #'
-#' @param x a POMDP solution (object of class POMDP).
+#' @family policy
+#' 
+#' @param x a solved [POMDP] object.
 #' @param belief specification of the current belief state (see argument start
-#' in \code{\link{POMDP}} for details). By default the belief state defined in
+#' in [POMDP] for details). By default the belief state defined in
 #' the model as start is used.
 #' @param epoch return reward for this epoch. Default is the first epoch.
-#' @return A list with the components \item{reward}{the total expected reward
-#' given a belief and epoch. } \item{belief_state}{the belief state specified
-#' in \code{belief}.} \item{pg_node}{the policy node that represents the belief
-#' state.} \item{action}{the optimal action.}
+#' 
+#' @return A list with the components 
+#' \item{reward}{the total expected reward
+#' given a belief and epoch. } 
+#' \item{belief_state}{the belief state specified
+#' in `belief`.} 
+#' \item{pg_node}{the policy node that represents the belief
+#' state.} 
+#' \item{action}{the optimal action.}
 #' @author Michael Hahsler
-#' @seealso \code{\link{POMDP}}, \code{\link{solve_POMDP}}
 #' @examples
-#'
 #' data("Tiger")
 #' sol <- solve_POMDP(model = Tiger)
 #'
@@ -35,13 +40,12 @@
 #' # Note that in this case, the total discounted expected reward is greater
 #' # than 10 since the tiger problem resets and another game staring with
 #' # a uniform belief is played which produces additional reward.
-#'
 #' @export
 reward <- function(x, belief = NULL, epoch = 1) {
   .solved_POMDP(x)
   
   if (is.null(belief))
-    belief <- x$model$start
+    belief <- x$start
   
   belief <- .translate_belief(belief, x)
   
@@ -57,7 +61,7 @@ reward <- function(x, belief = NULL, epoch = 1) {
     belief = belief,
     reward = vs$reward,
     pg_node = vs$pg_node,
-    action = factor(pg$action[vs$pg_node], levels = x$model$actions)
+    action = factor(pg$action[vs$pg_node], levels = x$actions)
   )
 }
 
