@@ -6,7 +6,8 @@ context("solve_POMDP")
 data("Tiger")
 sol <- solve_POMDP(Tiger)
 expect_identical(nrow(sol$solution$pg[[1]]), 5L)
-plot_policy_graph(sol)
+#plot_policy_graph(sol, belief = FALSE)
+plot_policy_graph(sol, belief = 1000)
 
 sol <- solve_POMDP(Tiger, horizon = 3, method = "incprune")
 expect_identical(length(sol$solution$pg), 3L)
@@ -38,14 +39,18 @@ context("solve_POMDP and model files")
 
 sol <- solve_POMDP("http://www.pomdp.org/examples/1d.POMDP")
 plot_policy_graph(sol, belief = FALSE)
+policy(sol)
 
 sol <- solve_POMDP("http://www.pomdp.org/examples/cheese.95.POMDP")
 plot_policy_graph(sol, belief = FALSE)
+policy(sol)
 
 sol <- solve_POMDP("http://www.pomdp.org/examples/shuttle.95.POMDP", 
                    parameter = list(fg_points = 10))
 plot_policy_graph(sol, belief = FALSE)
+policy(sol)
 
 sol <- solve_POMDP("http://www.pomdp.org/examples/stand-tiger.95.POMDP")
 plot_policy_graph(sol, belief = FALSE)
+policy(sol)
 
